@@ -444,6 +444,12 @@ matcher_map!(
         "tar",
         matchers::archive::is_tar
     ),
+    (
+        MatcherType::Archive,
+        "application/x-par2",
+        "par2",
+        matchers::archive::is_par2
+    ),
     (
         MatcherType::Archive,
         "application/vnd.rar",
@@ -462,6 +468,12 @@ matcher_map!(
         "bz2",
         matchers::archive::is_bz2
     ),
+    (
+        MatcherType::Archive,
+        "application/vnd.bzip3",
+        "bz3",
+        matchers::archive::is_bz3
+    ),
     (
         MatcherType::Archive,
         "application/x-7z-compressed",
@@ -570,6 +582,12 @@ matcher_map!(
         "zst",
         matchers::archive::is_zst
     ),
+    (
+        MatcherType::Archive,
+        "application/x-lz4",
+        "lz4",
+        matchers::archive::is_lz4
+    ),
     (
         MatcherType::Archive,
         "application/x-ole-storage",
